FlutterSystemAudio class final
Platform capability and permission helpers for system-audio capture.
Constructors
- FlutterSystemAudio({AudioFlutterPlatform? platform})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isSupported
→ Future<
bool> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listProcesses(
{AudioCancellationToken? cancellationToken}) → Future< List< AudioCaptureProcess> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermission(
{AudioCancellationToken? cancellationToken}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited